<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="33"/>
        <source>About Q Light Controller Plus</source>
        <translation>Über Q Light Controller Plus</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="88"/>
        <source>Contributors</source>
        <translation>Mitwirkende</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="135"/>
        <source>This application is licensed under the terms of the Apache 2.0 license.</source>
        <translation>Dieses Programm ist unter Apache 2.0 Bedingungen lizensiert.</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="42"/>
        <source>and contributors:</source>
        <translation>und Mitwirkende:</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="43"/>
        <source>Website: %1</source>
        <translation>Webseite: %1</translation>
    </message>
</context>
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Gerätemodus-Kanaleditor</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation>Verfügbare Kanäle</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Kanäle im Modus</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="123"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Unbekannte Dateinamenerweiterung: %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="147"/>
        <source>Fixture loading failed</source>
        <translation>Laden fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="app.cpp" line="148"/>
        <source>Unable to load fixture definition: </source>
        <translation>Gerätedefinition konnte nicht geladen werden: </translation>
    </message>
    <message>
        <location filename="app.cpp" line="242"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <location filename="app.cpp" line="243"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <location filename="app.cpp" line="248"/>
        <source>&amp;Open</source>
        <translation>&amp;Öffnen</translation>
    </message>
    <message>
        <location filename="app.cpp" line="249"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <location filename="app.cpp" line="254"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="app.cpp" line="255"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="260"/>
        <source>Save &amp;As...</source>
        <oldsource>Save &amp;As</oldsource>
        <translation>Speichern &amp;unter…</translation>
    </message>
    <message>
        <location filename="app.cpp" line="261"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation>CTRL+SHIFT+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="266"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="app.cpp" line="267"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <location filename="app.cpp" line="273"/>
        <source>Index</source>
        <translation>Handbuch</translation>
    </message>
    <message>
        <location filename="app.cpp" line="274"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="279"/>
        <source>About Fixture Definition Editor...</source>
        <translation>Über Fixture Definition Editor…</translation>
    </message>
    <message>
        <location filename="app.cpp" line="284"/>
        <source>About Qt...</source>
        <translation>Über Qt…</translation>
    </message>
    <message>
        <location filename="app.cpp" line="311"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="app.cpp" line="321"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="app.cpp" line="359"/>
        <source>Open a fixture definition</source>
        <translation>Eine Gerätedefinition öffnen</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Funktions-Assistent</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Werte</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Anfang</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>Der Anfangs-DMX-Wert</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Anzahl der DMX-Werte pro Funktion</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Anzahl</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Anzahl der Funktionen, die erstellt werden sollen</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>Der gemeinsame Basisname für alle Funktionen. Verwende die Raute &apos;#&apos;, um eine Nummerierung zu erstellen.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation>Funktion #</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Beispiel</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Liste der Funktionen, die mit diesen Einstellungen erstellt würden</translation>
    </message>
</context>
<context>
    <name>DocBrowser</name>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="105"/>
        <source>%1 - Document Browser</source>
        <translation>%1 - Handbuch</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="127"/>
        <source>Backward</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="128"/>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="129"/>
        <source>Index</source>
        <translation>Inhaltsverzeichnis</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="130"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="131"/>
        <source>Close this window</source>
        <translation>Dieses Fenster schließen</translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Kanal bearbeiten</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Überlappende Funktionen erkannt. Bitte beheben.&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation>Standardwert</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation>Voreinstellung</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Kanalname</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation>Farbe 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation>Farbe 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation>Wert 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation>Wert 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>Die Gruppe, zu der dieser Kanal gehört</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translatorcomment>Nicht ganz sicher über die Bedeutung. Yep, it&apos;s OK -Heikki</translatorcomment>
        <translation>Grob (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translatorcomment>Nicht ganz sicher über die Bedeutung. Yep, it&apos;s OK -Heikki</translatorcomment>
        <translation>Fein (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Funktionen</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Minimum value</source>
        <translation>Unterer Wert</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Maximum value</source>
        <translation>Oberer Wert</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Ausgewählte Funktion entfernen</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Funktions-Assistent</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="93"/>
        <source>Edit Channel: </source>
        <translation>Kanal bearbeiten: </translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Overlapping values</source>
        <translation>Überlappende Werte</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="498"/>
        <source>Open Gobo File</source>
        <translation>Öffne Gobo-Datei</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="501"/>
        <source>Gobo pictures</source>
        <translation>Gobo-Bilder</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Missing resources</source>
        <translation>Fehlende Ressourcen</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="616"/>
        <source>Some gobos are missing:

</source>
        <translation>Einige Gobos fehlen:

</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="482"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Einige Funktionen konnten aufgrund von überlappenden Werten nicht angelegt werden.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Head bearbeiten</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translatorcomment>Gibt es einen bessere Bezeichnung für Mode?</translatorcomment>
        <translation>Modus bearbeiten</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Modusname</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="78"/>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="83"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="91"/>
        <source>Add channel(s) to this mode</source>
        <translation>Kanal/Kanäle zum Modus hinzufügen</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="111"/>
        <source>Remove the selected channel</source>
        <translation>Ausgewählten Kanal entfernen</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="131"/>
        <source>Raise the selected channel</source>
        <translation>Ausgewählten Kanal nach oben verschieben</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="151"/>
        <source>Lower the selected channel</source>
        <translation>Ausgewählten Kanal nach unten verschieben</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="185"/>
        <source>Heads</source>
        <translation>Heads</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="198"/>
        <source>Head</source>
        <translation>Head</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Compose a new head</source>
        <translation>Neuen Head erstellen</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="226"/>
        <source>Remove the selected head</source>
        <translation>Ausgewählten Head entfernen</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="246"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Zugewiesene Kanäle des ausgewählten Heads bearbeiten</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="266"/>
        <source>Raise the selected head</source>
        <translation>Ausgewählten Head nach oben verschieben</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="286"/>
        <source>Lower the selected head</source>
        <translation>Ausgewählten Head nach unten verschieben</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="320"/>
        <source>Physical</source>
        <translation>Physisch</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="330"/>
        <source>Use global settings</source>
        <translation>Globale Einstellungen verwenden</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="340"/>
        <source>Override global settings</source>
        <translation>Globale Einstellungen überschreiben</translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Leuchtmittel</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lumen</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Farbtemperatur</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Maße</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Gewicht</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Tiefe</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation>Head(s)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Linse</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Min. Grad</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Max. Grad</translation>
    </message>
    <message>
        <source>Prism faces</source>
        <translation type="vanished">Prisma-Flächen</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Pan max. Grad</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Tilt max. Grad</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation>Anordnung
(Spalten x Zeilen)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Anschlussdaten</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Leistung</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>DMX-Anschluss</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Physische Informationen in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Physische Informationen aus der Zwischenablage einfügen</translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Hersteller</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>Der Name des Herstellers dieses Geräts (z.B.: Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Modell</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>Der Modellname dieses Geräts (z.B.: MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>Der Gerätetyp (z.B.: Moving Head)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="226"/>
        <source>LED Bar (Beams)</source>
        <translation>LED Bar (Strahlen)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="235"/>
        <source>LED Bar (Pixels)</source>
        <translation>LED Bar (Pixel)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <oldsource>The author name of this fixture definition</oldsource>
        <translation>Der Name des Autors dieser Gerätedefinition</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Einen Kanal hinzufügen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Ausgewählten Kanal entfernen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Ausgewählten Kanal bearbeiten</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Ausgewählten Kanal in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Kanal aus der Zwischenablage hier einfügen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Öffne/Schließe alle Kanäle</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Heads</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Einen Modus hinzufügen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Ausgewählten Modus entfernen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Ausgewählten Modus bearbeiten</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Eine Kopie des ausgewählten Modus erstellen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Öffne/Schließe alle Modi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation>Aliase</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation>Im Modus</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation>Neuen Alias hinzufügen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation>mit</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation>ersetze</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation>Ersetzter Kanal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation>Gesetzter Kanal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation>Ausgewählten Alias entfernen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation>Physisch</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="208"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>Willst du die Änderungen am Gerät
&quot;%1&quot;
vor dem Schließen speichern?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing important information</source>
        <translation>Wichtige Informationen fehlen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="238"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Fehlender Herstellername.
Kann Gerät nicht speichern.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="248"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Fehlender Modellname.
Kann Gerät nicht speichern.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Fixture saving failed</source>
        <translation>Speichern fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="279"/>
        <location filename="fixtureeditor.cpp" line="338"/>
        <source>Unable to save fixture definition:
%1</source>
        <oldsource>Unable to save fixture definition: </oldsource>
        <translation>Konnte die Gerätedefinition nicht speichern:
%1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="294"/>
        <source>Save fixture definition</source>
        <translation>Gerätedefinition speichern</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="371"/>
        <source>New Fixture</source>
        <translation>Neues Gerät</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="534"/>
        <source>Channel already exists</source>
        <translation>Kanal existiert bereits</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="449"/>
        <location filename="fixtureeditor.cpp" line="535"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>Ein Kanal mit dem Namen &quot;%1&quot; existiert bereits!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="541"/>
        <source>Channel has no name</source>
        <translation>Kanal hat keinen Namen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="457"/>
        <location filename="fixtureeditor.cpp" line="542"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Du musst dem Kanal einen beschreibenden Namen geben!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="494"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>Bist du dir sicher, dass du den Kanal %1 entfernen möchtest?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="813"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>Bist du dir sicher, dass du den Modus %1 entfernen möchtest?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="654"/>
        <location filename="fixtureeditor.cpp" line="689"/>
        <location filename="fixtureeditor.cpp" line="914"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="655"/>
        <location filename="fixtureeditor.cpp" line="691"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="656"/>
        <location filename="fixtureeditor.cpp" line="693"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="657"/>
        <location filename="fixtureeditor.cpp" line="695"/>
        <location filename="fixtureeditor.cpp" line="920"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="766"/>
        <location filename="fixtureeditor.cpp" line="775"/>
        <source>Unable to add mode</source>
        <translation>Modus kann nicht hinzugefügt werden</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="767"/>
        <source>Another mode by that name already exists</source>
        <translation>Ein anderer Modus mit diesem Namen existiert bereits</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="776"/>
        <source>You must give a name to the mode</source>
        <translation>Du musst dem Modus einen Namen geben</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="812"/>
        <source>Remove Mode</source>
        <translation>Modus entfernen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="860"/>
        <source>Rename new mode</source>
        <translation>Neuen Modus umbenennen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="861"/>
        <source>Give a unique name for the mode</source>
        <translation>Gib dem Modus einen eindeutigen Namen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="863"/>
        <source>Copy of %1</source>
        <translation>Kopie von %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="873"/>
        <source>Invalid name</source>
        <translation>Ungültiger Name</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="874"/>
        <source>Another mode by that name already exists.</source>
        <translation>Ein anderer Modus mit diesem Namen existiert bereits.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="917"/>
        <source>Clone</source>
        <translation>Klonen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="925"/>
        <source>Modes</source>
        <translation>Modi</translation>
    </message>
</context>
</TS>
